### Name: chol
### Title: Cholesky Factorization for Sparse Matrices
### Aliases: chol.spam chol,ANY-method chol,matrix-method chol,spam-method
###   chol chol.default
### Keywords: algebra

### ** Examples

# generate multivariate normals:
n <- 25    # dimension
N <- 1000  # sample size
Sigma <- .25^abs(outer(1:n,1:n,"-"))
Sigma <- as.spam( Sigma, eps=1e-4)

cholS <- chol( Sigma)    
# cholS is the upper triangular part of the permutated matrix Sigma
iord <- ordering(cholS, inv=TRUE)

R <- as.spam(cholS)[,iord]
mvsample <- array(rnorm(N*n),c(N,n)) %*% R

# 'mvsample' is of class 'spam'. We need to transform it to a
# regular matrix, as there is no method 'var' for 'spam' (should there?).
norm( var( as.matrix( mvsample)) - Sigma, type="HS")
norm( t(R) %*% R - Sigma, type="sup")




